#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 oeis
version:              0.3.10.2
visibility:           public
id:                   oeis-0.3.10.2-CWSZl1Y7YixuZINhhwzC5
key:                  oeis-0.3.10.2-CWSZl1Y7YixuZINhhwzC5
license:              BSD-3-Clause
maintainer:           Bartosz Nitka <niteria@gmail.com>
author:               Brent Yorgey
stability:            experimental
synopsis:
    Interface to the Online Encyclopedia of Integer Sequences (OEIS)

description:
    Interface to the <http://oeis.org/ Online Encyclopedia of Integer Sequences (OEIS)>.

category:             Math
abi:                  8a6bd990f76d8b0ca30dc4a9ac3de86a
exposed:              True
exposed-modules:      Math.OEIS Math.OEIS.Internal
hidden-modules:       Math.OEIS.Types
import-dirs:          /usr/lib/ghc-9.6.6/site-local/oeis-0.3.10.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/oeis-0.3.10.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/oeis-0.3.10.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-oeis
hs-libraries:         HSoeis-0.3.10.2-CWSZl1Y7YixuZINhhwzC5
depends:
    base-4.18.2.1 http-client-0.7.19-9meVfWioNG49hhaNpvORg0
    http-client-tls-0.3.6.4-9KaGRUfQlOcH11qQFZ8oLV
    http-types-0.12.4-4tdX51H3YCXI63KUlr8q5w
    network-3.1.4.0-57XjnahcYfrBnbtgCzAhJP
    network-uri-2.6.4.2-1K7fB5RWUkvJzcj2EjtnE4
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv

haddock-interfaces:   /usr/share/doc/haskell-oeis/html/oeis.haddock
haddock-html:         /usr/share/doc/haskell-oeis/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

